import React, { FC, useEffect, useState } from 'react';
import { styles } from './styles';
import { CheckboxModel } from './checkboxModels';
import { CheckIcon } from '../icons';
import { getThemeColorByDefaultColor } from '../../../utils';
import { TouchableOpacityButtonWrapper } from '../wrapper';

export const Checkbox: FC<CheckboxModel> = ({
  onCheckboxChange,
  isChecked= false,
  disabled= false,
}) => {
  const [isCheckboxChecked, setIsCheckboxChecked] = useState<boolean>(isChecked);

  useEffect(() => {
    onCheckboxChange && onCheckboxChange(isCheckboxChecked);
  }, [isCheckboxChecked]);

  const onCheck = () => setIsCheckboxChecked(!isCheckboxChecked);

  // @ts-ignore
  return (
    <TouchableOpacityButtonWrapper
      style={[styles().checkbox, isChecked && styles().checkboxSelected, disabled && styles().checkboxDisabled]}
      onClick={onCheck}
      disabled={disabled}
    >
      <>
        {isCheckboxChecked &&
          <CheckIcon
            color={getThemeColorByDefaultColor('text', 'extraLight')}
            width={'16'}
            height={'13'}
          />
        }
      </>
    </TouchableOpacityButtonWrapper>
  );
};
