import React from 'react';
import { RefreshControl, ScrollView, View } from 'react-native';
import { FC, useCallback, useState } from 'react';
import { styles } from './styles';

interface RefreshControlWrapperProps {
  onScreenRefresh?: () => void;
  stickyHeaderIndices?: number[];
  scrollEnabled?: boolean;
  children?: JSX.Element | JSX.Element[];
}

const wait = (timeout: number) => {
  // @ts-ignore
  return new Promise(resolve => setTimeout(resolve, timeout));
};

export const RefreshControlWrapper: FC<RefreshControlWrapperProps> = ({
  children,
  onScreenRefresh,
  stickyHeaderIndices = [],
  scrollEnabled =  true,
}) => {
  const [refreshing, setRefreshing] = useState(false);

  const onRefresh = useCallback(() => {
    onScreenRefresh && onScreenRefresh();
    setRefreshing(true);
    wait(3000).then(() => setRefreshing(false));
  }, []);

  return (
    <View style={[styles().container]}>
      <ScrollView
        scrollEnabled={scrollEnabled}
        stickyHeaderIndices={stickyHeaderIndices}
        contentContainerStyle={styles().scrollContainer}
        showsVerticalScrollIndicator={false}
        refreshControl={
          <RefreshControl
            refreshing={refreshing}
            onRefresh={onRefresh}
          />
        }
      >
        {children}
      </ScrollView>
    </View>
  );
};
