import React, { FC } from 'react';
import { Dimensions, TouchableOpacity, View } from 'react-native';
import { BottomSheet } from './components';
import { BottomSheetNavigationWrapperModel } from '../modalWrapperModels';

const windowHeight = Dimensions.get('window').height;

export const BottomSheetNavigationWrapper: FC<BottomSheetNavigationWrapperModel> = ({
  onCloseModal,
  isVisible = true,
  enableDropDownClose= true,
  modalHeight,
  children,
  showDragBar,
  backgroundColor= '#00000066',
}) => {
  const defaultModalHeight: number = typeof modalHeight === 'string'
    ? windowHeight * (parseFloat(modalHeight)/100)
    : modalHeight;

  const onClose = () => {
    enableDropDownClose && onCloseModal?.();
  };

  return (
    <View style={{ backgroundColor, height: windowHeight  }}>
      <TouchableOpacity style={{ height: windowHeight }} onPress={onClose} />
      <BottomSheet
        isVisible={isVisible}
        defaultHeight={defaultModalHeight}
        onClose={() => isVisible && onClose()}
        showDragBar={showDragBar}
        enableDropDownClose={enableDropDownClose}
      >
        {children}
      </BottomSheet>
    </View>
  );
};
