import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText, LabelMediumText } from '../../../atoms';
import { BooleanSlider } from '../../../molecules';
import { DragThumb, SpinnerThumb } from '../../../atoms/thumbs';
import { styles } from './styles';
import { AlarmEnableWidgetDetailModel } from '../widgetDetailModels';

const stateTypes = {
  OFF: 'OFF',
  ON: 'ON',
};

const stateToNumber = {
  [stateTypes.ON]: 1,
  [stateTypes.OFF]: 0,
};

export const AlarmEnableWidgetDetail: FC<AlarmEnableWidgetDetailModel> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  defaultValue = stateTypes.OFF,
  id,
  onUpdateData,
  loading = false,
  RightIcon,
  LeftIcon,
}) => {
  const loadingInfoText = loadingInfoTextOptions?.option1;
  const onChange = (value: number) => {
    const integerValue = value < 1 ? 0 : value;
    onUpdateData?.({ id, value: String(integerValue) });
  };

  return (
    <View>
      <View style={styles().alarmEnableInfoTextBlock}>
        <LabelMediumText>{title}</LabelMediumText>
        {!loading && <Body2RegularText color={styles().alarmEnableInfoTextBlock.color}>{subtitle}</Body2RegularText>}
        {loading &&
          <Body2RegularText color={styles().alarmEnableInfoTextBlock.color}>{loadingInfoText}</Body2RegularText>}
      </View>
      <BooleanSlider
        defaultValue={stateToNumber[defaultValue]}
        ThumbComponent={loading ? SpinnerThumb : DragThumb}
        IconLeft={LeftIcon}
        IconRight={RightIcon}
        onStateChange={onChange}
      />
    </View>
  );
};
