import React, { FC } from 'react';
import { View } from 'react-native';
import ColorPicker from 'react-native-wheel-color-picker';
import { CaptionMediumText } from '../../../../../atoms';
import { styles } from './styles';

interface Props {
  color: string;
  colorSampleTitle?: string;
  onColorChangeComplete: (color: string) => void;
  onInteractionStart: () => void;
  loading: boolean;
  enabled: boolean;
}

export const ColorWheelPicker:FC<Props> = ({
  color, 
  colorSampleTitle,
  onColorChangeComplete, 
  onInteractionStart,
  loading, 
  enabled,
}) => {

  return (
    <View
      style={styles().colorPickerWrapper}
      pointerEvents={loading || !enabled ? 'none' : 'auto'} 
    >
      <ColorPicker 
        color={color}
        onColorChangeComplete={onColorChangeComplete}
        onInteractionStart={onInteractionStart}
        sliderHidden={true}
        swatches={false}
        thumbSize={30}
      />
      <View style={styles().colorSampleWrapper}>
        <CaptionMediumText>{colorSampleTitle ? `${colorSampleTitle}:` : ''}</CaptionMediumText>
        <View style={[styles().colorSample, { backgroundColor: color }]}></View>
      </View>
    </View>
  );
};
