import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { LabelRegularText, LightOffIcon, LightOnIcon } from '../../../../../atoms';
import { DragThumb, SpinnerThumb } from '../../../../../atoms/thumbs';
import { ContinuousSlider } from '../../../../../molecules';
import { styles } from './styles';

interface Props {
  defaultValue?: number;
  onFinishChange?: (value: number) => void;
  loading?: boolean;
  sliderTitle?: string;
}

export const SetDimmer: FC<Props> = ({
  defaultValue = 0,
  onFinishChange,
  loading,
  sliderTitle,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  const handleOnFinish = (value: number) => {
    onFinishChange && onFinishChange(Math.round(value));
  };

  useEffect(() => {
    setValue(defaultValue);
  }, [defaultValue]);

  return (
    <View>
      <View style={styles().setDimmerTitle}>
        <LabelRegularText>{sliderTitle}</LabelRegularText>
      </View>
      <ContinuousSlider
        ThumbComponent={loading ? SpinnerThumb : DragThumb}
        IconLeft={LightOffIcon}
        IconRight={LightOnIcon}
        minValue={0}
        maxValue={100}
        onStateChange={(value) => setValue(value)}
        onFinishChange={handleOnFinish}
        defaultValue={value}
        isDisabled={loading}
      />
    </View>
  );
};
