import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import DropDownPicker, { ItemType } from 'react-native-dropdown-picker';
import { ModesInfoTextModel } from '../../../../widgetDetailModels';
import { styles } from '../styles';

interface Props {
  modesList: number[],
  modesTexts: ModesInfoTextModel,
  selectedItem: string,
  onSelectItem: (item: ItemType<number>) => void;
  isLoading: boolean;
}

interface ListItem {
  label: string,
  value: number
}

const thermostatModes = {
  OFF: '0',
  HOT: '1',
  COLD: '2',
  AUTO: '3',
  FAN_ONLY: '6',
  DRY: '8',
};

export const ModesSelector: FC<Props> = ({
  modesList,
  modesTexts,
  selectedItem,
  onSelectItem,
  isLoading,
}) => {
  const infoTextFromNumber = {
    [thermostatModes.HOT]: modesTexts.hot || '',
    [thermostatModes.COLD]: modesTexts.cold || '',
    [thermostatModes.AUTO]: modesTexts.auto || '',
    [thermostatModes.FAN_ONLY]: modesTexts.fanOnly || '',
    [thermostatModes.DRY]: modesTexts.dry || '',
  };

  const modesTextList: ListItem[] = modesList.map(
    (mode: number) => ({ label: infoTextFromNumber[mode], value: mode }),
  );

  const [open, setOpen] = useState<boolean>(false);
  const [value, setValue] = useState<number>(0);
  const [items, setItems] = useState<ListItem[]>(modesTextList);

  useEffect(() => {
    const value = modesList.find((item) => item === parseInt(selectedItem));
    value && setValue(value);
  }, [selectedItem]);

  return (
    <View>
      <DropDownPicker
        listMode='SCROLLVIEW'
        disabled={isLoading}
        placeholder='Select mode'
        open={open}
        onSelectItem={onSelectItem}
        value={value}
        items={items}
        setOpen={setOpen}
        setValue={setValue}
        setItems={setItems}
        dropDownDirection={'TOP'}
        itemSeparator={true}
        listItemLabelStyle={styles().modeThermostatItemLabel}
        listItemContainerStyle={styles().modeThermostatItemContainer}
        showArrowIcon={false}
        showTickIcon={false}
        itemSeparatorStyle={styles().modeThermostatItemSeparator}
        dropDownContainerStyle={styles().modeThermostatDropDownContainer}
        textStyle={styles().modeThermostatText}
        disabledStyle={styles().modeThermostatDisabled}
        containerStyle={styles().modeThermostatContainer}
        style={styles().modeThermostatSelectButton}
      />
    </View>
  );
};
