import React, { FC, useEffect, useState } from 'react';
import DropDownPicker from 'react-native-dropdown-picker';
import { styles } from '../styles';
import { View } from 'react-native';

interface ListItem {
  label: string,
  value: number
}

interface Props {
  isLoading: boolean;
  showList: boolean;
  onSelectValue: (val: ListItem) => void;
  defaultValue: number;
  valuesList: ListItem[];
  placeholderWhenEmpty: string;
}

export const Selector: FC<Props> = ({
  onSelectValue,
  defaultValue= 0,
  valuesList,
  isLoading,
  showList = false,
  placeholderWhenEmpty,
}) => {
  const [open, setOpen] = useState<boolean>(showList);
  const [value, setValue] = useState<number>(defaultValue);
  const [items, setItems] = useState<ListItem[]>(valuesList);

  const onShowList = () => setOpen(!open);

  useEffect(()=> {
    setValue(defaultValue);
  }, [defaultValue]);

  return (
    <View>
      <DropDownPicker
        listMode='SCROLLVIEW'
        disabled={isLoading}
        placeholder={placeholderWhenEmpty}
        open={open}
        onSelectItem={(val) => onSelectValue(val as ListItem)}
        value={value}
        items={items}
        setOpen={onShowList}
        setValue={setValue}
        setItems={setItems}
        dropDownDirection={'TOP'}
        itemSeparator={true}
        listItemLabelStyle={styles().modeThermostatItemLabel}
        listItemContainerStyle={styles().modeThermostatItemContainer}
        showArrowIcon={false}
        showTickIcon={false}
        itemSeparatorStyle={styles().modeThermostatItemSeparator}
        dropDownContainerStyle={styles().modeThermostatDropDownContainer}
        textStyle={styles().modeThermostatText}
        disabledStyle={styles().modeThermostatDisabled}
        containerStyle={styles().modeThermostatContainer}
        style={styles().modeThermostatSelectButton}
      />
    </View>
  );
};
