import { ShutterInfoTextOptionsModel } from './shutter/components/shutterModels';
import { FC } from 'react';

export type BinaryDefaultValue = 'ON' | 'OFF';
export type TripleDefaultValue = 'ON' | 'OFF' | 'EMPTY';
export type WidgetDetailBinaryValue = 'ON' | 'OFF';

export interface WidgetDetailModel {
  id: string;
  title?: string;
  subtitle?: string;
  loadingInfoTextOptions?: LoadingInfoTextModel;
  value?: string;
  defaultValue?: string;
  onUpdateData?: (value: SettingDataOutputModel) => void;
  loading?: boolean;
}

export interface DeviceItemModel {
  id: string;
  masterId: string;
  masterType: string;
  masterName: string;
  name: string;
  type: string;
  roomId: string;
  usage: string | null;
  isParent: boolean;
  link: string;
  state: string | number;
  options: DeviceOptionsModel | null;
}

export interface DeviceOptionsModel {
  minTemp: number;
  maxTemp: number;
  step: number;
  modes: number[];
  fanModes: number[];
}

export interface BinaryDoorWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'>
{ defaultValue?: BinaryDefaultValue }

export interface AlarmEnableWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'> {
  defaultValue?: BinaryDefaultValue;
  LeftIcon: FC<any>;
  RightIcon: FC<any>;
}

export interface TripleDoorWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'>
{ defaultValue?: TripleDefaultValue }

export interface SwitchWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'value'>
{ subtitle?: BinarySubtitleModel, value?: WidgetDetailBinaryValue }

export interface SwitchAndDimmerWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'value'>
{
  subtitle?: BinarySubtitleModel,
  value?: number,
  sliderTitle?: string,
}

export interface RGBDimmerWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'onUpdateData'>
{
  dimmerValue?: number,
  colorPickerValue?: string,
  subtitle?: BinarySubtitleModel,
  colorSampleTitle?: string;
  sliderTitle?: string,
  onChangeColor?: (value: SettingDataOutputModel) => void,
  onChangeDimmer?: (value: SettingRgbDimmerDataOutputModel) => void,
}

export interface GradualShutterWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'title' | 'loadingInfoTextOptions'>
{
  widgetName?: string,
  widgetInfoTextOptions?: ShutterInfoTextOptionsModel,
  quickActionButtonsTextOptions?: QuickActionButtonsTextModel,
  quickActionsTitle?: string,
  controlPanelTitle?: string,
  loadingInfoTextOptions?: ShutterLoadingInfoTextModel,
}

export interface GradualShutterWithSlatsWidgetDetailModel
{
  shutterConfig: ShutterConfigModel,
  slatsConfig: SlatsConfigModel,
}

export interface ThermostatWidgetDetailModel {
  switchConfig?: SwitchThermostatConfigModel;
  setPointConfig?: SetPointThermostatConfigModel;
  ambientConfig?: AmbientTemperatureThermostatConfigModel,
  fanModeConfig?: FanModeThermostatConfigModel | null,
  modeConfig?: ModeThermostatConfigModel,
  isThermostatEnabled: boolean;
}

export interface LoadingInfoTextModel {
  option1?: string;
  option2?: string;
  option3?: string;
}

export interface ShutterLoadingInfoTextModel {
  opening?: string;
  closing?: string;
  stopping?: string;
}

export interface ModesInfoTextModel {
  hot?: string;
  cold?: string;
  auto?: string;
  fanOnly?: string;
  dry?: string;
}

export interface SpeedsInfoTextModel {
  off?: string;
  auto?: string;
  low?: string;
  medium?: string;
  fast?: string;
}

export interface QuickActionButtonsTextModel {
  open?: string;
  close?: string;
}

export interface BinarySubtitleModel {
  on?: string;
  off?: string;
}

export interface SettingDataOutputModel {
  id: string;
  value: string;
}

export interface SettingRgbDimmerDataOutputModel extends Omit<SettingDataOutputModel, 'value'> {
  value: number;
}

export interface OptionsConfigModel {
  label: string,
  value: number
}

export interface SwitchThermostatConfigModel {
  switchTitle: string;
  switchSubtitle: BinarySubtitleModel;
  switchLoadingTextOptions: LoadingInfoTextModel;
  switchIsLoading: boolean;
  switchVisible: boolean;
  onChangeSwitch: (val: boolean) => void;
}

export interface SetPointThermostatConfigModel {
  setPointId: string;
  setPointValue: string;
  setPointTitle: string;
  setPointSubtitle: string;
  setPointStep: number;
  setPointMinValue: number;
  setPointMaxValue: number;
  setPointIsLoading: boolean;
  onChangeSetPointValue: (value: SettingDataOutputModel) => void;
}

export interface AmbientTemperatureThermostatConfigModel {
  ambientTemperatureTitle: string;
  ambientTemperatureId: string;
  ambientTemperatureValue: string;
}

export interface FanModeThermostatConfigModel {
  fanModeId: string;
  fanModeValue: number;
  fanModeOptions: OptionsConfigModel[];
  fanModeSelectorTitle: string;
  fanModeSelectorPlaceholder: string;
  fanModeIsLoading: boolean;
  onChangeFanModeValue: (value: SettingDataOutputModel) => void;
}

export interface ModeThermostatConfigModel {
  modeId: string;
  modeValue: number;
  modeOptions: OptionsConfigModel[];
  modeSelectorTitle: string;
  modeSelectorPlaceholder: string;
  modeIsLoading: boolean;
  onChangeModeValue: (value: SettingDataOutputModel) => void;
}

export interface ShutterConfigModel {
  shutterId: string;
  shutterValue: string;
  shutterTitle: string;
  shutterInfoTextOptions: ShutterInfoTextOptionsModel;
  quickActionButtonsTextOptions: QuickActionButtonsTextModel;
  quickActionsTitle: string;
  shutterLoadingInfoTextOptions: ShutterLoadingInfoTextModel;
  shutterControlPanelTitle: string;
  isShutterLoading: boolean;
  onChangeShutterValue: (value: SettingDataOutputModel) => void;
}

export interface SlatsConfigModel {
  slatsId: string;
  slatsValue: string;
  slatsControlPanelTitle: string;
  isSlatsLoading: boolean;
  onChangeSlatsValue: (value: SettingDataOutputModel) => void;
}
